==> soap-tck-2.0.0.zip: soap-tck/src/com/sun/ts/tests/saaj/api/jakarta_xml_soap/Detail/URLClient.java <==
/*
 * Copyright (c) 2007, 2020 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

/*
 * $Id$
 */

package com.sun.ts.tests.saaj.api.jakarta_xml_soap.Detail;

import com.sun.ts.lib.util.*;
import com.sun.ts.lib.porting.*;
import com.sun.ts.lib.harness.*;

import java.io.*;
import java.net.*;
import java.util.*;
import java.rmi.*;

import com.sun.javatest.Status;

public class URLClient extends EETest {
  private static final String PROTOCOL = "http";

  private static final String HOSTNAME = "localhost";

  private static final int PORTNUM = 8000;

  private static final String DETAIL_TESTSERVLET = "/Detail_web/DetailTestServlet";

  private static final String WEBSERVERHOSTPROP = "webServerHost";

  private static final String WEBSERVERPORTPROP = "webServerPort";

  private TSURL tsurl = new TSURL();

  private URL url = null;

  private URLConnection urlConn = null;

  private Properties props = null;

  private String hostname = HOSTNAME;

  private int portnum = PORTNUM;

  public static void main(String[] args) {
    URLClient theTests = new URLClient();
    Status s = theTests.run(args, System.out, System.err);
    s.exit();
  }

  /* Test setup */

  /*
   * @class.setup_props: webServerHost; webServerPort;
   */

  public void setup(String[] args, Properties p) throws Fault {
    props = p;
    boolean pass = true;

    try {
      hostname = p.getProperty(WEBSERVERHOSTPROP);
      if (hostname == null)
        pass = false;
      else if (hostname.equals(""))
        pass = false;
      try {
        portnum = Integer.parseInt(p.getProperty(WEBSERVERPORTPROP));
      } catch (Exception e) {
        pass = false;
      }
    } catch (Exception e) {
      throw new Fault("setup failed:", e);
    }
    if (!pass) {
      TestUtil.logErr(
          "Please specify host & port of web server " + "in config properties: "
              + WEBSERVERHOSTPROP + ", " + WEBSERVERPORTPROP);
      throw new Fault("setup failed:");
    }
    logMsg("setup ok");
  }

  public void cleanup() throws Fault {
    logMsg("cleanup ok");
  }

  /*
   * @testName: addDetailEntryTest1
   *
   * @assertion_ids: SAAJ:JAVADOC:310; SAAJ:JAVADOC:311;
   *
   * @test_Strategy: Call Detail.addDetailEntry(Name).
   *
   * Description: Adds the given Name object to this Detail object.
   *
   */
  public void addDetailEntryTest1() throws Fault {
    boolean pass = true;
    try {
      TestUtil.logMsg("addDetailEntryTest1: add DetailEntry Name "
          + "object to this Detail object");
      TestUtil.logMsg("protocol=" + PROTOCOL + ", hostname=" + hostname
          + ", portnum=" + portnum + ", servlet=" + DETAIL_TESTSERVLET);
      TestUtil.logMsg("Creating url to test servlet.....");
      url = tsurl.getURL(PROTOCOL, hostname, portnum, DETAIL_TESTSERVLET);
      TestUtil.logMsg(url.toString());
      for (int i = 0; i < 2; i++) {
        TestUtil.logMsg("Sending post request to test servlet.....");
        props.setProperty("TESTNAME", "addDetailEntryTest1");
        if (i == 0)
          props.setProperty("SOAPVERSION", "soap11");
        else
          props.setProperty("SOAPVERSION", "soap12");
        urlConn = TestUtil.sendPostData(props, url);
        TestUtil.logMsg("Getting response from test servlet.....");
        Properties resProps = TestUtil.getResponseProperties(urlConn);
        if (!resProps.getProperty("TESTRESULT").equals("pass"))
          pass = false;
      }

    } catch (Exception e) {
      TestUtil.logErr("Caught exception: " + e.getMessage());
      e.printStackTrace();
      throw new Fault("addDetailEntryTest1 failed", e);
    }

    if (!pass)
      throw new Fault("addDetailEntryTest1 failed");
  }

  /*
   * @testName: addDetailEntryTest2
   *
   * @assertion_ids: SAAJ:JAVADOC:312; SAAJ:JAVADOC:313;
   *
   * @test_Strategy: Call Detail.addDetailEntry(QName).
   *
   * Description: Adds the given Name object to this Detail object.
   *
   */
  public void addDetailEntryTest2() throws Fault {
    boolean pass = true;
    try {
      TestUtil.logMsg("addDetailEntryTest2: add DetailEntry Name "
          + "object to this Detail object");
      TestUtil.logMsg("protocol=" + PROTOCOL + ", hostname=" + hostname
          + ", portnum=" + portnum + ", servlet=" + DETAIL_TESTSERVLET);
      TestUtil.logMsg("Creating url to test servlet.....");
      url = tsurl.getURL(PROTOCOL, hostname, portnum, DETAIL_TESTSERVLET);
      TestUtil.logMsg(url.toString());
      for (int i = 0; i < 2; i++) {
        TestUtil.logMsg("Sending post request to test servlet.....");
        props.setProperty("TESTNAME", "addDetailEntryTest2");
        if (i == 0)
          props.setProperty("SOAPVERSION", "soap11");
        else
          props.setProperty("SOAPVERSION", "soap12");
        urlConn = TestUtil.sendPostData(props, url);
        TestUtil.logMsg("Getting response from test servlet.....");
        Properties resProps = TestUtil.getResponseProperties(urlConn);
        if (!resProps.getProperty("TESTRESULT").equals("pass"))
          pass = false;
      }

    } catch (Exception e) {
      TestUtil.logErr("Caught exception: " + e.getMessage());
      e.printStackTrace();
      throw new Fault("addDetailEntryTest2 failed", e);
    }

    if (!pass)
      throw new Fault("addDetailEntryTest2 failed");
  }

  /*
   * @testName: getDetailEntriesTest
   *
   * @assertion_ids: SAAJ:JAVADOC:314;
   *
   * @test_Strategy: Call Detail.getDetailEntries().
   *
   * Description: Gets a list of the detail entries in this Detail object.
   *
   */
  public void getDetailEntriesTest() throws Fault {
    boolean pass = true;
    try {
      TestUtil.logMsg("getDetailEntriesTest: get a list of the "
          + "DetailEntry objects in this Detail object");
      TestUtil.logMsg("Creating url to test servlet.....");
      url = tsurl.getURL(PROTOCOL, hostname, portnum, DETAIL_TESTSERVLET);
      TestUtil.logMsg(url.toString());
      for (int i = 0; i < 2; i++) {
        TestUtil.logMsg("Sending post request to test servlet.....");
        props.setProperty("TESTNAME", "getDetailEntriesTest");
        if (i == 0)
          props.setProperty("SOAPVERSION", "soap11");
        else
          props.setProperty("SOAPVERSION", "soap12");
        urlConn = TestUtil.sendPostData(props, url);
        TestUtil.logMsg("Getting response from test servlet.....");
        Properties resProps = TestUtil.getResponseProperties(urlConn);
        if (!resProps.getProperty("TESTRESULT").equals("pass"))
          pass = false;
      }

    } catch (Exception e) {
      TestUtil.logErr("Caught exception: " + e.getMessage());
      e.printStackTrace();
      throw new Fault("getDetailEntriesTest failed", e);
    }

    if (!pass)
      throw new Fault("getDetailEntriesTest failed");
  }
}

==> soap-tck-2.0.1.zip: soap-tck/src/com/sun/ts/tests/saaj/api/jakarta_xml_soap/Detail/URLClient.java <==
/*
 * Copyright (c) 2007, 2020 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

/*
 * $Id$
 */

package com.sun.ts.tests.saaj.api.jakarta_xml_soap.Detail;

import java.net.URL;
import java.net.URLConnection;
import java.util.Properties;

import com.sun.javatest.Status;
import com.sun.ts.lib.harness.EETest;
import com.sun.ts.lib.porting.TSURL;
import com.sun.ts.lib.util.TestUtil;

public class URLClient extends EETest {
  private static final String PROTOCOL = "http";

  private static final String HOSTNAME = "localhost";

  private static final int PORTNUM = 8000;

  private static final String DETAIL_TESTSERVLET = "/Detail_web/DetailTestServlet";

  private static final String WEBSERVERHOSTPROP = "webServerHost";

  private static final String WEBSERVERPORTPROP = "webServerPort";

  private TSURL tsurl = new TSURL();

  private URL url = null;

  private URLConnection urlConn = null;

  private Properties props = null;

  private String hostname = HOSTNAME;

  private int portnum = PORTNUM;

  public static void main(String[] args) {
    URLClient theTests = new URLClient();
    Status s = theTests.run(args, System.out, System.err);
    s.exit();
  }

  /* Test setup */

  /*
   * @class.setup_props: webServerHost; webServerPort;
   */

  public void setup(String[] args, Properties p) throws Fault {
    props = p;
    boolean pass = true;

    try {
      hostname = p.getProperty(WEBSERVERHOSTPROP);
      if (hostname == null)
        pass = false;
      else if (hostname.equals(""))
        pass = false;
      try {
        portnum = Integer.parseInt(p.getProperty(WEBSERVERPORTPROP));
      } catch (Exception e) {
        pass = false;
      }
    } catch (Exception e) {
      throw new Fault("setup failed:", e);
    }
    if (!pass) {
      TestUtil.logErr(
          "Please specify host & port of web server " + "in config properties: "
              + WEBSERVERHOSTPROP + ", " + WEBSERVERPORTPROP);
      throw new Fault("setup failed:");
    }
    logMsg("setup ok");
  }

  public void cleanup() throws Fault {
    logMsg("cleanup ok");
  }

  /*
   * @testName: addDetailEntryTest1
   *
   * @assertion_ids: SAAJ:JAVADOC:310; SAAJ:JAVADOC:311;
   *
   * @test_Strategy: Call Detail.addDetailEntry(Name).
   *
   * Description: Adds the given Name object to this Detail object.
   *
   */
  public void addDetailEntryTest1() throws Fault {
    boolean pass = true;
    try {
      TestUtil.logMsg("addDetailEntryTest1: add DetailEntry Name "
          + "object to this Detail object");
      TestUtil.logMsg("protocol=" + PROTOCOL + ", hostname=" + hostname
          + ", portnum=" + portnum + ", servlet=" + DETAIL_TESTSERVLET);
      TestUtil.logMsg("Creating url to test servlet.....");
      url = tsurl.getURL(PROTOCOL, hostname, portnum, DETAIL_TESTSERVLET);
      TestUtil.logMsg(url.toString());
      for (int i = 0; i < 2; i++) {
        TestUtil.logMsg("Sending post request to test servlet.....");
        props.setProperty("TESTNAME", "addDetailEntryTest1");
        if (i == 0)
          props.setProperty("SOAPVERSION", "soap11");
        else
          props.setProperty("SOAPVERSION", "soap12");
        urlConn = TestUtil.sendPostData(props, url);
        TestUtil.logMsg("Getting response from test servlet.....");
        Properties resProps = TestUtil.getResponseProperties(urlConn);
        if (!resProps.getProperty("TESTRESULT").equals("pass"))
          pass = false;
      }

    } catch (Exception e) {
      TestUtil.logErr("Caught exception: " + e.getMessage());
      e.printStackTrace();
      throw new Fault("addDetailEntryTest1 failed", e);
    }

    if (!pass)
      throw new Fault("addDetailEntryTest1 failed");
  }

  /*
   * @testName: addDetailEntryTest2
   *
   * @assertion_ids: SAAJ:JAVADOC:312; SAAJ:JAVADOC:313;
   *
   * @test_Strategy: Call Detail.addDetailEntry(QName).
   *
   * Description: Adds the given Name object to this Detail object.
   *
   */
  public void addDetailEntryTest2() throws Fault {
    boolean pass = true;
    try {
      TestUtil.logMsg("addDetailEntryTest2: add DetailEntry Name "
          + "object to this Detail object");
      TestUtil.logMsg("protocol=" + PROTOCOL + ", hostname=" + hostname
          + ", portnum=" + portnum + ", servlet=" + DETAIL_TESTSERVLET);
      TestUtil.logMsg("Creating url to test servlet.....");
      url = tsurl.getURL(PROTOCOL, hostname, portnum, DETAIL_TESTSERVLET);
      TestUtil.logMsg(url.toString());
      for (int i = 0; i < 2; i++) {
        TestUtil.logMsg("Sending post request to test servlet.....");
        props.setProperty("TESTNAME", "addDetailEntryTest2");
        if (i == 0)
          props.setProperty("SOAPVERSION", "soap11");
        else
          props.setProperty("SOAPVERSION", "soap12");
        urlConn = TestUtil.sendPostData(props, url);
        TestUtil.logMsg("Getting response from test servlet.....");
        Properties resProps = TestUtil.getResponseProperties(urlConn);
        if (!resProps.getProperty("TESTRESULT").equals("pass"))
          pass = false;
      }

    } catch (Exception e) {
      TestUtil.logErr("Caught exception: " + e.getMessage());
      e.printStackTrace();
      throw new Fault("addDetailEntryTest2 failed", e);
    }

    if (!pass)
      throw new Fault("addDetailEntryTest2 failed");
  }

  /*
   * @testName: getDetailEntriesTest
   *
   * @assertion_ids: SAAJ:JAVADOC:314;
   *
   * @test_Strategy: Call Detail.getDetailEntries().
   *
   * Description: Gets a list of the detail entries in this Detail object.
   *
   */
  public void getDetailEntriesTest() throws Fault {
    boolean pass = true;
    try {
      TestUtil.logMsg("getDetailEntriesTest: get a list of the "
          + "DetailEntry objects in this Detail object");
      TestUtil.logMsg("Creating url to test servlet.....");
      url = tsurl.getURL(PROTOCOL, hostname, portnum, DETAIL_TESTSERVLET);
      TestUtil.logMsg(url.toString());
      for (int i = 0; i < 2; i++) {
        TestUtil.logMsg("Sending post request to test servlet.....");
        props.setProperty("TESTNAME", "getDetailEntriesTest");
        if (i == 0)
          props.setProperty("SOAPVERSION", "soap11");
        else
          props.setProperty("SOAPVERSION", "soap12");
        urlConn = TestUtil.sendPostData(props, url);
        TestUtil.logMsg("Getting response from test servlet.....");
        Properties resProps = TestUtil.getResponseProperties(urlConn);
        if (!resProps.getProperty("TESTRESULT").equals("pass"))
          pass = false;
      }

    } catch (Exception e) {
      TestUtil.logErr("Caught exception: " + e.getMessage());
      e.printStackTrace();
      throw new Fault("getDetailEntriesTest failed", e);
    }

    if (!pass)
      throw new Fault("getDetailEntriesTest failed");
  }
}
